@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2017-01-06'; # DATE
-our $VERSION = '0.36'; # VERSION
+our $DATE = '2017-01-09'; # DATE
+our $VERSION = '0.37'; # VERSION
 
 use 5.010001;
 use strict;
@@ -142,7 +142,7 @@ sub munge_files {
             ($self->extra_urls_for_version ? (extra_urls_for_version => [split(/\s*,\s*/, $self->extra_urls_for_version)]) : ()),
             default_log_level => $self->default_log_level,
             pass_cmdline_object => $self->pass_cmdline_object,
-            cmdline => $self->cmdline,
+            (cmdline => $self->cmdline) x !!defined($self->cmdline),
             prefer_lite => $self->prefer_lite,
             ssl_verify_hostname => $self->ssl_verify_hostname,
             code_before_instantiate_cmdline => $code_before_instantiate_cmdline,
@@ -253,7 +253,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.36 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-01-06.
+This document describes version 0.37 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-01-09.
 
 =head1 SYNOPSIS
 
@@ -445,7 +445,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-GenPericmdScript>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-ScriptFromFunc>.
 
 =head1 BUGS
 
